const fs = require('fs');

const readFile = (filename) => {
    try {
        return fs.readFileSync(filename, { encoding: 'utf-8' });
    } catch (error) {
        throw new Error(`File: ${filename} doesn\'t exist`);
    }
};

const createRequestObj = (request, urlParts) => {
    return Object.assign({}, request.url, { 
        query: urlParts.query, 
        path: urlParts.pathname,  
        method: request.method,
    });
};

const createResponseObj = (response) => {   
    return {
        sendFile: (filename) => {
            response.writeHead(200, { 'Content-Type': 'text/html' });
            response.end(readFile(filename));
        },
        send: (data) => response.end(data),
        sendJSON: (data) => {
            response.writeHead(200, { 'ContentT-Type': 'application/json' });
            response.end(JSON.stringify(data));
        },
        stream: (data) => response.write(data),
        endStream: () => response.end(),
        redirect: (redirectUrl) => {
            console.log('In redirect');
            response.writeHead(301, { 'Location': redirectUrl });
            response.end();
        }
    };
};

module.exports = {
    readFile,
    createRequestObj,
    createResponseObj
};
